
from setuptools import setup

with open("README.md", "r") as f:
    long_description = f.read()

# This call to setup() does all the work
setup(
    name="helloCasechhavi",
    version="1.0.0",
    descp="The hello world package",
    long_descp=long_description,
    long_descp_content="text/markdown",
    author="Chhavi Trivedi",
    authoremail="chhavi7320@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["newPackage"],
    include_package_data=True,
    # install_requires=,
    entry_points={
        "console_scripts": [
            "py_case=newPackage.__main__:main",
        ]
    },
)



import argparse


def main():
    # Initializing Parser
    parser = argparse.ArgumentParser(description='Hello World')
    # Adding Argument
    parser.add_argument("-u", "--upperr", type=str, nargs='+',
                        metavar="uppercase", default='', help="Uppercase")
    parser.add_argument("-l", "--lowerr", type=str, nargs='+',
                        metavar="lowercase", default='', help="Lowercase")
    args = parser.parse_args()
    for i in range(0, len(args.upperr)):
        if args.upperr != '':
            print(args.upperr[i].upper())
        if args.lowerr != '':
            print(args.lowerr[i].lower())


if __name__ == "__main__":
    main()
